@@ -2,6 +2,7 @@
 
 import os
 import ee
+import time
 from ee.ee_exception import EEException
 import gcsfs
 import logging
@@ -522,6 +523,7 @@ def export_daily_surface_water(
     look_back=30,
     lag=4,
     output_confidence=False,
+    output_flood = False,
     fusion_samples=None,
     fusion_model_asset=None,
     output_asset_path=None,
@@ -589,11 +591,11 @@ def export_daily_surface_water(
 
             for i in range(n):
                 if output_asset_path is not None:
-                    output_asset_tile = output_asset_path + f"daily_tile{i}"
+                    output_asset_tile = output_asset_path + f"daily_tile{i:05d}"
                 else:
                     output_asset_tile = None
                 if output_bucket_path is not None:
-                    output_bucket_tile = output_bucket_path + f"_tile{i}"
+                    output_bucket_tile = output_bucket_path + f"_tile{i:05d}"
                 else:
                     output_bucket_tile = None
 
@@ -608,6 +610,7 @@ def export_daily_surface_water(
                     look_back,
                     lag,
                     output_confidence,
+                    output_flood,
                     fusion_samples,
                     fusion_model_asset,
                     output_asset_tile,
@@ -661,8 +664,10 @@ def export_daily_surface_water(
         else:
             harmonic_coefs = harmonic_coefs.select("^(c|t|s).*")
 
+        prod_region = region.buffer(250000)
+
         ds, label = _fuse_dataset(
-            region,
+            prod_region,
             start_time,
             end_time,
             fusion_model,
@@ -713,13 +718,20 @@ def export_daily_surface_water(
             fused_pred,
             initial_threshold=initial_threshold,
             edge_buffer=300,
-            region=region,
+            region=prod_region,
             invert=True,
             reduction_scale=200,
             return_threshold=True,
         )
 
-        water = fused_pred.gt(ci_threshold).rename("water").uint8()
+        # ci_threshold = ee.Number(ee.Algorithms.If(ci_threshold.lt(-0.1),-0.1,ci_threshold))
+
+        permanent_water = ee.Image("JRC/GSW1_2/GlobalSurfaceWater").select("occurrence").unmask(0).gt(80)
+        water = fused_pred.gt(ci_threshold).Or(permanent_water).rename("water").uint8()
+
+        if output_flood:
+            flood = water.select("water").And(permanent_water.Not()).rename("flood")
+            water = water.addBands(flood)
 
         if output_confidence:
             weights_err = weights_lr.select(".*(x|y|n)$")
@@ -845,8 +857,63 @@ def export_daily_surface_water(
 
     return
 
+def merge_gcp_tiled_results(bucket_path,pattern,region,retries=-1,clean_up=False,cloud_project=None,file_dims=None):
+    land_area = (
+        ee.FeatureCollection("USDOS/LSIB_SIMPLE/2017")
+        .filterBounds(region)
+        .geometry(100)
+        .buffer(2500, maxError=100)
+    )
+    grid = geeutils.tile_region(region, intersect_geom=land_area, grid_size=1.0)
+
+    expected_n = grid.size().getInfo()
+
+    fcomponents = bucket_path.split("/")
+    bucket = fcomponents[2]
+    fpath = pattern.replace("*","")
+
+    files = utils.list_gcs_objs(bucket, pattern=pattern, project=cloud_project)
+
+    if len(files) == expected_n:
+        images = [ee.Image.loadGeoTIFF(file) for file in files]
+
+        merged = ee.ImageCollection.fromImages(images).mosaic()
+
+        export_region = region.bounds(maxError=100).getInfo()["coordinates"]
+        # bucket_path, ext = os.path.splitext(output_bucket_path)
+
+        now = datetime.datetime.now()
+        time_id = now.strftime("%Y%m%d%H%M%s")
+
+        task = ee.batch.Export.image.toCloudStorage(
+            image=merged,
+            description=f"hydrafloods_merge_gcp_export_{time_id}",
+            bucket=bucket,
+            fileNamePrefix=fpath,
+            region=export_region,
+            scale=10,
+            crs="EPSG:4326",
+            fileDimensions=file_dims,
+            maxPixels=1e13,
+            fileFormat="GeoTIFF",
+            formatOptions={"cloudOptimized": True},
+        )
+        task.start()
+
+        if clean_up:
+            gcsfs.GCSFileSystem.rm(files)
+        
+    elif retries > 0:
+        time.sleep(60*10)
+        
+        merge_gcp_tiled_results(bucket_path,pattern,region,retries=(retries-1))
+
+    else:
+        raise RuntimeError(f"could not find all expected tiles to merge...found {len(files)} tiles but expected {expected_n}")
+
+    return
 
 if __name__ == "__main__":
     raise NotImplementedError(
-        "Application is currently not implemented, please check back later"
+        "Worklow is currently not implemented for CLI use, please check back later"
     )
